"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FolderAndFile = exports.focusedFolderTreeView = void 0;
const vscode = require("vscode");
const path_1 = require("path");
class focusedFolderTreeView {
    constructor(extensionContext, workspaceRoot) {
        this.extensionContext = extensionContext;
        this.workspaceRoot = workspaceRoot;
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
        this.settings = {
            lastFocusOnLoad: false,
            lastFocused: "",
        };
        this.getSettings();
        if (this.settings.lastFocusOnLoad && this.settings.lastFocused) {
            this.selectFolder(vscode.Uri.parse(this.settings.lastFocused));
        }
    }
    getSettings() {
        this.settings = {
            lastFocusOnLoad: vscode.workspace
                .getConfiguration("focusedFolder")
                .get("rememberLastFocus"),
            lastFocused: this.workspaceRoot
                ? this.extensionContext.workspaceState.get("rsl-vsc-focused-folder.rememberLastFocus")
                : this.extensionContext.globalState.get("rsl-vsc-focused-folder.rememberLastFocus"),
        };
    }
    setLastFocused(uri) {
        if (this.workspaceRoot) {
            this.extensionContext.workspaceState.update("rsl-vsc-focused-folder.rememberLastFocus", uri);
        }
        else {
            this.extensionContext.globalState.update("rsl-vsc-focused-folder.rememberLastFocus", uri);
        }
    }
    recursiveFolder(uri) {
        return __awaiter(this, void 0, void 0, function* () {
            const folderArray = yield vscode.workspace.fs.readDirectory(uri);
            return folderArray
                .sort((a, b) => b[1] - a[1])
                .map((item) => {
                const [name, type] = item;
                const isDirectory = type === vscode.FileType.Directory
                    ? vscode.TreeItemCollapsibleState.Collapsed
                    : vscode.TreeItemCollapsibleState.None;
                return new FolderAndFile(name, isDirectory, vscode.Uri.joinPath(uri, "/" + name));
            });
        });
    }
    refresh() {
        this._onDidChangeTreeData.fire();
    }
    selectFolder(uri) {
        return __awaiter(this, void 0, void 0, function* () {
            if (uri) {
                this.selectedFolder = uri;
                this.setLastFocused(uri.path);
            }
            else {
                this.selectedFolder = undefined;
                this.setLastFocused(undefined);
            }
            this.refresh();
        });
    }
    getTreeItem(element) {
        return __awaiter(this, void 0, void 0, function* () {
            return element;
        });
    }
    getChildren(element) {
        return __awaiter(this, void 0, void 0, function* () {
            if (element) {
                return this.recursiveFolder(element.resourceUri);
            }
            else {
                return this.selectedFolder
                    ? [
                        new FolderAndFile(`${path_1.basename(this.selectedFolder.path)} (Focused)`, vscode.TreeItemCollapsibleState.Expanded, this.selectedFolder).setContextValue("focusedBaseFolder"),
                    ]
                    : Promise.resolve([]);
            }
        });
    }
}
exports.focusedFolderTreeView = focusedFolderTreeView;
class FolderAndFile extends vscode.TreeItem {
    constructor(label, collapsibleState, uri) {
        super(label, collapsibleState);
        this.label = label;
        this.collapsibleState = collapsibleState;
        this.tooltip = this.label;
        this.resourceUri = uri;
        this.command =
            collapsibleState === vscode.TreeItemCollapsibleState.None
                ? {
                    arguments: [this],
                    command: "focusedFolderView.openFile",
                    title: this.label,
                }
                : undefined;
    }
    setContextValue(value) {
        this.contextValue = value;
        return this;
    }
}
exports.FolderAndFile = FolderAndFile;
//# sourceMappingURL=focusedFolderTreeView.js.map